.. _swh-indexer:

.. include:: README.rst

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   README.md
   metadata-workflow.rst
   swhpkg.rst


Reference Documentation
-----------------------

.. toctree::
   :maxdepth: 2

   cli

.. only:: standalone_package_doc

   Indices and tables
   ------------------

   * :ref:`genindex`
   * :ref:`modindex`
   * :ref:`search`
